@@ -102,6 +102,9 @@ class RecognizeResult:
     response: Optional[str] = None
     """Key for intent response."""
 
+    context: Dict[str, Any] = field(default_factory=dict)
+    """Context values acquired during matching."""
+
 
 def recognize(
     text: str,
@@ -276,6 +279,7 @@ def recognize_all(
                         },
                         entities_list=maybe_match_context.entities,
                         response=response,
+                        context=maybe_match_context.intent_context,
                     )
 
 
